@@ -1,12 +1,7 @@
-#coding:utf-8
-"""
-Created on 27.02.2010
-
-@author: akvarats
-"""
+# coding: utf-8
+from __future__ import absolute_import
 
 from m3_ext.ui.base import ExtUIComponent
-
 from m3_ext.ui.misc import ExtDataStore
 
 
@@ -40,7 +35,7 @@ class BaseExtField(ExtUIComponent):
         # Этот текст будет выводиться, если поле незаполненно
         self.empty_text = None
 
-        # Минимальные длина поля и текст ошибки, если длина была превышена
+        # Минимальные длина поля и текст ошибки, если длина не была достигнута
         self.min_length = self.min_length_text = None
 
         # Максимальные длина поля и текст ошибки, если длина была превышена
