@@ -1,7 +1,8 @@
-# -*- coding: utf-8 -*-
-# Create your views here.rtn.core.views
-from django.shortcuts import render_to_response
+# coding: utf-8
+from __future__ import absolute_import
+
 from django import template as django_template
+from django.shortcuts import render_to_response
 
 from m3_ext.context_processors import DesktopProcessor
 
@@ -14,7 +15,7 @@ def workspace(
     context_processors=DEFAULT_PROCESSORS
 ):
     u"""
-    Возвращает view для тображения Рабочего Стола
+    Возвращает view для отображения Рабочего Стола
     на основе указанного шаблона
     :param template: имя файла шаблона
     :type template: str
